==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_el.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Χωρίς αποτελέσματα αναζήτησης</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Είστε σίγουροι ότι θέλετε να απεγκαταστήσετε το %1 ;</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Επιβεβαίωση</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Αφαιρέστε από την επιφάνεια εργασίας</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Αφαιρέστε από την πλατφόρμα</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Απεγκατάσταση</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation>Άνοιγμα</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Αποστολή στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Αποστολή στην πλατφόρμα</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Αφαίρεση από την εκκίνηση</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Πρόσθεση στην εκκίνηση</translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Όλες οι Εφαρμογές</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Διαδίκτυο</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Συνομιλία</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Μουσική</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Γραφικά</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Παιχνίδι</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Γραφείο</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Γίνεται ανάγνωση</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Προγραμματισμός</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Σύστημα</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Άλλα</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Είστε σίγουροι ότι θέλετε να απεγκαταστήσετε το %1 ;</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>Όλες οι εξαρτήσεις θα απομακρυνθούν μαζί</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Επιβεβαίωση</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Υπολογιστής</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Έγγραφα</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Μουσική</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Εικόνες</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Λήψεις</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Κλείδωμα</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Αποσύνδεση</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Επανεκκίνηση</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Αναστολή</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Τερματισμός λειτουργίας</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Πίσω</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Υπολογιστής</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Μουσική</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Τερματισμός λειτουργίας</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Κλείδωμα</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Αποσύνδεση</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Επανεκκίνηση</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Αναστολή</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Πίσω</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Έγγραφα</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Εικόνες</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Λήψεις</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Υπολογιστής</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Μουσική</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Λήψεις</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Μη αυτόματα</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Τερματισμός λειτουργίας</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Εικόνες</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Αναζήτηση</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Είστε σίγουροι ότι θέλετε να απεγκαταστήσετε το %1 ;</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Επιβεβαίωση</translation>
    </message>
</context>
</TS>

==> dde-launcher_4.6.13.orig.tar.xz: dde-launcher-4.6.13/translations/dde-launcher_el.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Χωρίς αποτελέσματα αναζήτησης</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Διαδίκτυο</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Συνομιλία</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Μουσική</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Γραφικά</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Γραφείο</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Γίνεται ανάγνωση</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Προγραμματισμός</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Σύστημα</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Παιχνίδια</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Άλλο</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Επιβεβαίωση</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Αφαιρέστε από την επιφάνεια εργασίας</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Αφαιρέστε από την πλατφόρμα</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Απεγκατάσταση</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation>Άνοιγμα</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Αποστολή στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Αποστολή στην πλατφόρμα</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Αφαίρεση από την εκκίνηση</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Πρόσθεση στην εκκίνηση</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Όλες οι Εφαρμογές</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Διαδίκτυο</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Συνομιλία</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Μουσική</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Γραφικά</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Παιχνίδι</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Γραφείο</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Γίνεται ανάγνωση</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Προγραμματισμός</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Σύστημα</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Άλλα</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Υπολογιστής</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Έγγραφα</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Μουσική</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Εικόνες</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Λήψεις</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Κλείδωμα</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Αποσύνδεση</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Επανεκκίνηση</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Αναστολή</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Τερματισμός λειτουργίας</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Πίσω</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Υπολογιστής</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Μουσική</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Τερματισμός λειτουργίας</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Κλείδωμα</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Αποσύνδεση</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Επανεκκίνηση</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Αναστολή</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Πίσω</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Έγγραφα</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Εικόνες</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Λήψεις</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Υπολογιστής</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Μουσική</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Λήψεις</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Μη αυτόματα</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Εικόνες</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Έγγραφα</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Ενέργεια</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation>Πίσω</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Αναζήτηση</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Επιβεβαίωση</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
